## Description

Summarize what changes were made in this Merge Request.
- List any major functionality changes or additions.
- Explain any major design decisions, or encountered problems. 
- Include relevant resources, e.g. with links to StackOverflow answers or blog posts.

## Related Issues

Issues resolved by this MR: 
- fixes #...
- fixes #...

Issues related to this MR, but not resolved by it:
- related to #...
- related to #...

## Checklist

- [ ] Formatting matches prescribed [style](https://gitlab.tudelft.nl/demoses/demoses-coupling/-/blob/main/README.dev.md?ref_type=heads)
- [ ] Tests pass
- [ ] Code coverage does not decrease
- [ ] New tests have been added for new code
- [ ] User-facing changes have been listed in [CHANGELOG.md]
